@@ -1,5 +1,5 @@
-from typing import NamedTuple, Union, List, Sequence, Any
-import os
+from typing import TypeVar
+
 import numpy as np
 from d3m_types.sequence import ndarray
 from primitive_interfaces.supervised_learning import SupervisedLearnerPrimitiveBase
@@ -13,7 +13,6 @@ Params = TypeVar('Params')
 
 
 class JMIFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params]):
-
     __author__ = "RPI DARPA D3M"
 
     """
@@ -40,7 +39,7 @@ class JMIFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params]
 
     def __init__(self):
         super().__init__()
-        
+
         self.is_feature_selection = True
         self.hyperparameters = {}
         self.training_inputs = None
@@ -68,7 +67,7 @@ class JMIFeatureSelector(SupervisedLearnerPrimitiveBase[Inputs, Outputs, Params]
             raise ValueError('Missing training data, or missing values exist.')
 
         index = JMI_BF(self.training_inputs, self.training_outputs)
-        print (index.shape[0])
+        print(index.shape[0])
 
         if index.shape == ():
             raise ValueError('Feature selection failed.')
